@@ -32,6 +32,7 @@ from . import (
     xdmf,
 )
 from .__about__ import __version__
+from ._common import topological_dimension
 from ._exceptions import ReadError, WriteError
 from ._helpers import extension_to_filetype, read, write, write_points_cells
 from ._mesh import CellBlock, Mesh
@@ -76,5 +77,6 @@ __all__ = [
     "CellBlock",
     "ReadError",
     "WriteError",
+    "topological_dimension",
     "__version__",
 ]
