@@ -7,7 +7,7 @@ import warnings
 import numpy as np
 
 from ..__about__ import __version__
-from .._common import _topological_dimension
+from .._common import topological_dimension
 from .._files import open_file
 from .._helpers import register
 from .._mesh import Mesh
@@ -169,7 +169,7 @@ def _write_cells(f, block, index=None):
     if len(block) == 0:
         return
     pmap = np.array(meshio_to_netgen_pmap[block.type])
-    dim = _topological_dimension[block.type]
+    dim = topological_dimension[block.type]
     post_data = []
     pre_data = []
     i_index = 0
@@ -219,7 +219,7 @@ def _write_codim_domain_data(f, mesh, cells_index, dim, codim):
         for block, index in zip(mesh.cells, cells_index):
             if index is None:
                 continue
-            if _topological_dimension[block.type] == dim - codim:
+            if topological_dimension[block.type] == dim - codim:
                 indices = indices.union(set(index))
 
         for idx in indices:
@@ -385,7 +385,7 @@ def write_buffer(f, mesh, float_fmt):
             cells_index = [None] * len(mesh.cells)
 
     for block in mesh.cells:
-        cells_per_dim[_topological_dimension[block.type]] += len(block)
+        cells_per_dim[topological_dimension[block.type]] += len(block)
 
     f.write(f"# Generated by meshio {__version__}\n")
     f.write("mesh3d\n\n")
@@ -400,14 +400,14 @@ def write_buffer(f, mesh, float_fmt):
     f.write("surfaceelements\n")
     f.write(f"{cells_per_dim[2]}\n")
     for block, index in zip(mesh.cells, cells_index):
-        if _topological_dimension[block.type] == 2:
+        if topological_dimension[block.type] == 2:
             _write_cells(f, block, index)
 
     f.write("\n#  matnr      np      p1      p2      p3      p4\n")
     f.write("volumeelements\n")
     f.write(f"{cells_per_dim[3]}\n")
     for block, index in zip(mesh.cells, cells_index):
-        if _topological_dimension[block.type] == 3:
+        if topological_dimension[block.type] == 3:
             _write_cells(f, block, index)
 
     f.write(
@@ -416,7 +416,7 @@ def write_buffer(f, mesh, float_fmt):
     f.write("edgesegmentsgi2\n")
     f.write(f"{cells_per_dim[1]}\n")
     for block, index in zip(mesh.cells, cells_index):
-        if _topological_dimension[block.type] == 1:
+        if topological_dimension[block.type] == 1:
             _write_cells(f, block, index)
 
     f.write("\n#          X             Y             Z\n")
@@ -434,7 +434,7 @@ def write_buffer(f, mesh, float_fmt):
     f.write("pointelements\n")
     f.write(f"{cells_per_dim[0]}\n")
     for block, index in zip(mesh.cells, cells_index):
-        if _topological_dimension[block.type] == 0:
+        if topological_dimension[block.type] == 0:
             _write_cells(f, block, index)
 
     # currently, there is no better place for identification data
