@@ -1,9 +1,10 @@
-import helpers
 import numpy as np
 import pytest
 
 import meshio
 
+from . import helpers
+
 test_set_full = [
     helpers.empty_mesh,
     helpers.line_mesh,
@@ -25,17 +26,17 @@ test_set_full = [
 
 @pytest.mark.parametrize("mesh", test_set_full)
 @pytest.mark.parametrize("compression", [None, "gzip"])
-def test_xdmf3(mesh, compression):
+def test_xdmf3(mesh, compression, tmp_path):
     def write(*args, **kwargs):
         return meshio.xdmf.write(*args, compression=compression, **kwargs)
 
-    helpers.write_read(write, meshio.xdmf.read, mesh, 1.0e-14)
+    helpers.write_read(tmp_path, write, meshio.xdmf.read, mesh, 1.0e-14)
 
 
-def test_generic_io():
+def test_generic_io(tmp_path):
     with pytest.warns(UserWarning):
-        helpers.generic_io("test.hmf")
+        helpers.generic_io(tmp_path / "test.hmf")
 
     with pytest.warns(UserWarning):
         # With additional, insignificant suffix:
-        helpers.generic_io("test.0.hmf")
+        helpers.generic_io(tmp_path / "test.0.hmf")
