@@ -22,17 +22,17 @@ from . import helpers
         helpers.add_cell_data(helpers.tri_mesh, [("medit:ref", (), int)]),
     ],
 )
-def test_io(mesh):
-    helpers.write_read(meshio.medit.write, meshio.medit.read, mesh, 1.0e-15)
+def test_io(mesh, tmp_path):
+    helpers.write_read(tmp_path, meshio.medit.write, meshio.medit.read, mesh, 1.0e-15)
 
 
-def test_generic_io():
-    helpers.generic_io("test.mesh")
+def test_generic_io(tmp_path):
+    helpers.generic_io(tmp_path / "test.mesh")
     # With additional, insignificant suffix:
-    helpers.generic_io("test.0.mesh")
+    helpers.generic_io(tmp_path / "test.0.mesh")
     # same for binary files
-    helpers.generic_io("test.meshb")
-    helpers.generic_io("test.0.meshb")
+    helpers.generic_io(tmp_path / "test.meshb")
+    helpers.generic_io(tmp_path / "test.0.meshb")
 
 
 # same tests with ugrid format files converted with UGC from
