@@ -43,7 +43,7 @@ test_set = [
 @pytest.mark.parametrize(
     "data_type", [(False, None), (True, None), (True, "lzma"), (True, "zlib")]
 )
-def test(mesh, data_type):
+def test(mesh, data_type, tmp_path):
     binary, compression = data_type
 
     def writer(*args, **kwargs):
@@ -52,13 +52,13 @@ def test(mesh, data_type):
     # ASCII files are only meant for debugging, VTK stores only 11 digits
     # <https://gitlab.kitware.com/vtk/vtk/issues/17038#note_264052>
     tol = 1.0e-15 if binary else 1.0e-10
-    helpers.write_read(writer, meshio.vtu.read, mesh, tol)
+    helpers.write_read(tmp_path, writer, meshio.vtu.read, mesh, tol)
 
 
-def test_generic_io():
-    helpers.generic_io("test.vtu")
+def test_generic_io(tmp_path):
+    helpers.generic_io(tmp_path / "test.vtu")
     # With additional, insignificant suffix:
-    helpers.generic_io("test.0.vtu")
+    helpers.generic_io(tmp_path / "test.0.vtu")
 
 
 @pytest.mark.parametrize(
@@ -78,7 +78,3 @@ def test_read_from_file(filename, ref_cells, ref_num_cells, ref_num_pnt):
     assert ref_cells == mesh.cells[0].type
     assert len(mesh.cells[0].data) == ref_num_cells
     assert len(mesh.points) == ref_num_pnt
-
-
-if __name__ == "__main__":
-    test(helpers.tet10_mesh, (True, None))
